@@ -1,3 +1,5 @@
+# Copyright (c) 2020, The InferLO authors. All rights reserved.
+# Licensed under the Apache License, Version 2.0 - see LICENSE file.
 import abc
 
 import numpy as np
@@ -38,9 +40,20 @@ class DiscreteDomain(Domain):
 
     @staticmethod
     def binary():
-        """Creates somain with two values 0 and 1."""
+        """Creates domain with two values 0 and 1."""
         return DiscreteDomain([0, 1])
 
+    @staticmethod
+    def range(n: int):
+        """Creates domain with integer values from 0 to n-1."""
+        return DiscreteDomain(range(n))
+
+    def __repr__(self):
+        return 'DiscreteDomain([%s])' % ','.join([str(v) for v in self.values])
+
 
 class RealDomain(Domain):
-    """All real values."""
+    """Domain consisting of all real values."""
+
+    def __repr__(self):
+        return 'RealDomain'
