@@ -1,3 +1,5 @@
+# Copyright (c) 2020, The InferLO authors. All rights reserved.
+# Licensed under the Apache License, Version 2.0 - see LICENSE file.
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Iterable
@@ -12,9 +14,9 @@ if TYPE_CHECKING:
 
 
 class GenericGraphModel(GraphModel):
-    """Graphical base in the most general form.
+    """Graphical model in the most general form.
 
-    Explicitly specified by factors.
+    Explicitly specified by list of factors.
     """
 
     def __init__(self, num_variables: int, domain=None):
