@@ -1,21 +1,24 @@
+# Copyright (c) 2020, The InferLO authors. All rights reserved.
+# Licensed under the Apache License, Version 2.0 - see LICENSE file.
 import numpy as np
 
-from inferlo.pairwise.testing import (tree_potts_model,
-                                      line_potts_model, assert_results_close)
+from inferlo import PairWiseFiniteModel
+from inferlo.testing import (tree_potts_model,
+                             line_potts_model, assert_results_close)
 
 
 def test_vert15_alph2():
     model = tree_potts_model(gr_size=10, al_size=2, seed=123)
-    gt = model.infer(algorithm='bruteforce')
+    ground_truth = model.infer(algorithm='bruteforce')
     result = model.infer(algorithm='tree_dp')
-    assert_results_close(result, gt)
+    assert_results_close(result, ground_truth)
 
 
 def test_vert5_alph3():
     model = tree_potts_model(gr_size=5, al_size=3, seed=123)
-    gt = model.infer(algorithm='bruteforce')
+    ground_truth = model.infer(algorithm='bruteforce')
     result = model.infer(algorithm='tree_dp')
-    assert_results_close(result, gt)
+    assert_results_close(result, ground_truth)
 
 
 def test_long_line():
@@ -38,3 +41,11 @@ def test_big_tree():
     result = model.infer(algorithm='tree_dp')
     assert np.allclose(result.marg_prob,
                        np.ones((gr_size, al_size)) / al_size)
+
+
+def test_fully_isolated():
+    model = PairWiseFiniteModel(10, 2)
+    model.set_field(np.random.random(size=(10, 2)))
+    ground_truth = model.infer(algorithm='bruteforce')
+    result = model.infer(algorithm='tree_dp')
+    assert_results_close(result, ground_truth)
