@@ -1,3 +1,5 @@
+# Copyright (c) 2020, The InferLO authors. All rights reserved.
+# Licensed under the Apache License, Version 2.0 - see LICENSE file.
 from functools import lru_cache
 
 import numpy as np
@@ -7,15 +9,16 @@ import numpy as np
 
 
 def decode_state(state_id, vert_num, al_size):
-    """Converts integer id to state."""
-    return [(state_id // (al_size ** (vert_num - j - 1))) % al_size for j in
-            range(vert_num)]
+    """Converts integer id to state.
+
+    Can also be applied to np.array with multiple state ids.
+    """
+    return [(state_id // (al_size ** j)) % al_size for j in range(vert_num)]
 
 
 def encode_state(state, vert_num, al_size):
     """Converts states to integer id."""
-    return sum(
-        [state[j] * (al_size ** (vert_num - j - 1)) for j in range(vert_num)])
+    return np.dot(state, al_size ** np.arange(vert_num))
 
 
 @lru_cache(maxsize=None)
@@ -24,8 +27,8 @@ def decode_all_states(vert_num, al_size):
 
     Returns np.array of shape(states_count, vert_num).
     """
-    n = al_size ** vert_num
-    return np.array([decode_state(i, vert_num, al_size) for i in range(n)])
+    state_ids = np.arange(al_size ** vert_num)
+    return np.array(decode_state(state_ids, vert_num, al_size)).T
 
 
 @lru_cache(maxsize=None)
